|ShapeOut2|
===========

|PyPI Version| |Tests Status Linux| |Tests Status Win| |Coverage Status| |Docs Status|


**Shape-Out 2** is the successor of
`Shape-Out <https://github.com/ZELLMECHANIK-DRESDEN/ShapeOut>`__,
a graphical user interface for the analysis and visualization of RT-DC data sets.
For more information please visit https://zellmechanik.com/.


Documentation
-------------

The documentation, including the code reference and examples, is available at
`shapeout2.readthedocs.io <https://shapeout2.readthedocs.io>`__.


Installation
------------
Installers for Windows and macOS are available at the `release page <https://github.com/ZELLMECHANIK-DRESDEN/ShapeOut2/releases>`__.

If you have Python 3 installed, you can install Shape-Out 2 with

::

    pip install shapeout2


Citing Shape-Out
----------------
Please cite Shape-Out either in-line

::

  (...) using the analysis software Shape-Out version 2.X.X (available at
  https://github.com/ZELLMECHANIK-DRESDEN/ShapeOut2).

or in a bibliography

::

  Paul Müller and others (2019), Shape-Out version 2.X.X: Analysis software
  for real-time deformability cytometry [Software]. Available at
  https://github.com/ZELLMECHANIK-DRESDEN/ShapeOut2.

and replace ``2.X.X`` with the version of Shape-Out that you used.


Testing
-------

::

    pip install -e .
    python setup.py test
    

.. |ShapeOut2| image:: https://raw.github.com/ZELLMECHANIK-DRESDEN/ShapeOut2/master/docs/logo/shapeout2_h50.png
.. |PyPI Version| image:: https://img.shields.io/pypi/v/ShapeOut2.svg
   :target: https://pypi.python.org/pypi/ShapeOut2
.. |Tests Status Linux| image:: https://img.shields.io/travis/ZELLMECHANIK-DRESDEN/ShapeOut2.svg?label=tests_linux
   :target: https://travis-ci.com/ZELLMECHANIK-DRESDEN/ShapeOut2
.. |Tests Status Win| image:: https://img.shields.io/appveyor/ci/paulmueller/ShapeOut2/master.svg?label=tests_win
   :target: https://ci.appveyor.com/project/paulmueller/ShapeOut2
.. |Coverage Status| image:: https://img.shields.io/codecov/c/github/ZELLMECHANIK-DRESDEN/ShapeOut2/master.svg
   :target: https://codecov.io/gh/ZELLMECHANIK-DRESDEN/ShapeOut2
.. |Docs Status| image:: https://readthedocs.org/projects/ShapeOut2/badge/?version=latest
   :target: https://readthedocs.org/projects/shapeout2/builds/
